Struct phper_alloc::EBox[][src]

pub struct EBox<T: EAllocatable> { /* fields omitted */ }
The Box which use php emalloc and efree to manage memory.

TODO now feature allocator_api is still unstable, implement myself, use Box<T, Alloc> later.

Implementations

impl<T: EAllocatable> EBox<T>[src]

pub fn new(x: T) -> Self[src]

Allocates heap memory using emalloc then places x into it.

Panic

Panic if size_of::<T>() equals zero.

pub unsafe fn from_raw(raw: *mut T) -> Self[src]

Constructs from a raw pointer.

pub fn into_raw(b: EBox<T>) -> *mut T[src]

Consumes and returning a wrapped raw pointer.

Will leak memory.