pub trait EAllocatable { fn free(ptr: *mut Self) { ... } }
The item which can be placed into container EBox.
The method to free the heap allocated by emalloc, should call efree at the end.
emalloc
efree