RefClone

Trait RefClone 

pub trait RefClone {
    // Required method
    fn ref_clone(&mut self) -> Self;
}
Duplicate an object without deep copy, but to only add the refcount, for php refcount struct.

Required Methods

fn ref_clone(&mut self) -> Self

Returns a refcount value with same reference of the value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors