Type Definition phper_alloc::EBox [−][src]
type EBox<T> = Box<T>;
The Box which use php emalloc and efree to manage memory.
TODO now feature allocator_api is still unstable, using global allocator instead.
type EBox<T> = Box<T>;
The Box which use php emalloc and efree to manage memory.
TODO now feature allocator_api is still unstable, using global allocator instead.