Type Definition phper_alloc::EVec [−][src]
type EVec<T> = Vec<T>;
The Vec which use php emalloc and efree to manage memory.
TODO now feature allocator_api is still unstable, using global allocator instead.
type EVec<T> = Vec<T>;
The Vec which use php emalloc and efree to manage memory.
TODO now feature allocator_api is still unstable, using global allocator instead.