Trait phper_alloc::EAllocatable[][src]

pub trait EAllocatable {
    fn free(ptr: *mut Self) { ... }
}
The item which can be placed into container EBox.

Provided methods

fn free(ptr: *mut Self)[src]

The method to free the heap allocated by emalloc, should call efree at the end.

Loading content...

Implementors

Loading content...