Trait phper_alloc::EAllocatable [−][src]
The item which can be placed into container EBox.
Provided methods
fn free(ptr: *mut Self)[src]
The method to free the heap allocated by emalloc, should call efree at the end.