pub trait ToRefOwned {
type Owned: Borrow<Self>;
// Required method
fn to_ref_owned(&mut self) -> Self::Owned;
}Expand description
Duplicate an object without deep copy, but to only add the refcount, for php refcount struct.
Required Associated Types
Required Methods
Sourcefn to_ref_owned(&mut self) -> Self::Owned
fn to_ref_owned(&mut self) -> Self::Owned
Creates owned data from borrowed data, by increasing refcount.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".